package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmMaintenanceProcess;

/**
 * 检修计划全流程管理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-05
 */
public interface PdmMaintenanceProcessMapper 
{
    /**
     * 查询检修计划全流程管理
     * 
     * @param id 检修计划全流程管理主键
     * @return 检修计划全流程管理
     */
    public PdmMaintenanceProcess selectPdmMaintenanceProcessById(Long id);

    /**
     * 查询检修计划全流程管理列表
     * 
     * @param pdmMaintenanceProcess 检修计划全流程管理
     * @return 检修计划全流程管理集合
     */
    public List<PdmMaintenanceProcess> selectPdmMaintenanceProcessList(PdmMaintenanceProcess pdmMaintenanceProcess);

    /**
     * 新增检修计划全流程管理
     * 
     * @param pdmMaintenanceProcess 检修计划全流程管理
     * @return 结果
     */
    public int insertPdmMaintenanceProcess(PdmMaintenanceProcess pdmMaintenanceProcess);

    /**
     * 修改检修计划全流程管理
     * 
     * @param pdmMaintenanceProcess 检修计划全流程管理
     * @return 结果
     */
    public int updatePdmMaintenanceProcess(PdmMaintenanceProcess pdmMaintenanceProcess);

    /**
     * 删除检修计划全流程管理
     * 
     * @param id 检修计划全流程管理主键
     * @return 结果
     */
    public int deletePdmMaintenanceProcessById(Long id);

    /**
     * 批量删除检修计划全流程管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmMaintenanceProcessByIds(Long[] ids);
}
